@@ -1,4 +1,3 @@
-# coding: utf-8
 """
 This module provides support for Unix shell-style wildcards
 """
@@ -20,6 +19,7 @@ class WildCard:
     >>> w.filter("foo.nc")
     ['foo.nc']
     """
+
     def __init__(self, wildcard, sep="|"):
         """
         Initializes a WildCard.
@@ -34,7 +34,7 @@ class WildCard:
             self.pats = wildcard.split(sep)
 
     def __str__(self):
-        return "<%s, patterns = %s>" % (self.__class__.__name__, self.pats)
+        return f"<{self.__class__.__name__}, patterns = {self.pats}>"
 
     def filter(self, names):
         """
