@@ -75,7 +75,9 @@ def reverse_readfile(filename: Union[str, Path]) -> Generator[str, str, None]:
         return
 
 
-def reverse_readline(m_file, blk_size=4096, max_mem=4000000) -> Generator[str, str, None]:
+def reverse_readline(
+    m_file, blk_size=4096, max_mem=4000000
+) -> Generator[str, str, None]:
     """
     Generator method to read a file line-by-line, but backwards. This allows
     one to efficiently get data at the end of a file.
@@ -193,7 +195,9 @@ class FileLock:
         self.is_locked = False
 
         if self.delay > self.timeout or self.delay <= 0 or self.timeout <= 0:
-            raise ValueError("delay and timeout must be positive with delay " "<= timeout")
+            raise ValueError(
+                "delay and timeout must be positive with delay " "<= timeout"
+            )
 
     def acquire(self):
         """
