@@ -2,13 +2,15 @@
 Helpful regex based functions. E.g., grepping.
 """
 
-import re
 import collections
+import re
 
-from monty.io import zopen, reverse_readfile
+from monty.io import reverse_readfile, zopen
 
 
-def regrep(filename, patterns, reverse=False, terminate_on_match=False, postprocess=str):
+def regrep(
+    filename, patterns, reverse=False, terminate_on_match=False, postprocess=str
+):
     r"""
     A powerful regular expression version of grep.
 
@@ -34,11 +36,13 @@ def regrep(filename, patterns, reverse=False, terminate_on_match=False, postproc
     compiled = {k: re.compile(v) for k, v in patterns.items()}
     matches = collections.defaultdict(list)
     gen = reverse_readfile(filename) if reverse else zopen(filename, "rt")
-    for i, l in enumerate(gen):
+    for i, line in enumerate(gen):
         for k, p in compiled.items():
-            m = p.search(l)
+            m = p.search(line)
             if m:
-                matches[k].append([[postprocess(g) for g in m.groups()], -i if reverse else i])
+                matches[k].append(
+                    [[postprocess(g) for g in m.groups()], -i if reverse else i]
+                )
         if terminate_on_match and all(len(matches.get(k, [])) for k in compiled.keys()):
             break
     try:
