@@ -4,11 +4,10 @@ Calling shell processes.
 import shlex
 import threading
 import traceback
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
 
 from .string import is_string
 
-
 __author__ = "Matteo Giantomass"
 __copyright__ = "Copyright 2014, The Materials Virtual Lab"
 __version__ = "0.1"
