@@ -40,6 +40,16 @@ class GoodMSONClass(MSONable):
         )
 
 
+class LimitedMSONClass(MSONable):
+    """An MSONable class that only accepts a limited number of options"""
+
+    def __init__(self, a):
+        self.a = a
+
+    def __eq__(self, other):
+        return self.a == other.a
+
+
 class GoodNestedMSONClass(MSONable):
     def __init__(self, a_list, b_dict, c_list_dict_list, **kwargs):
         assert isinstance(a_list, list)
@@ -90,6 +100,23 @@ def my_callable(a, b):
     return a + b
 
 
+class EnumNoAsDict(Enum):
+    name_a = "value_a"
+    name_b = "value_b"
+
+
+class EnumAsDict(Enum):
+    name_a = "value_a"
+    name_b = "value_b"
+
+    def as_dict(self):
+        return {"v": self.value}
+
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["v"])
+
+
 class EnumTest(MSONable, Enum):
     a = 1
     b = 2
@@ -202,10 +229,17 @@ class TestMSONable:
                 "list5": [GMC(15, 15.0, "fifteen")],
             },
         ]
-        obj = GoodNestedMSONClass(a_list=a_list, b_dict=b_dict, c_list_dict_list=c_list_dict_list)
+        obj = GoodNestedMSONClass(
+            a_list=a_list, b_dict=b_dict, c_list_dict_list=c_list_dict_list
+        )
 
-        assert a_list[0].unsafe_hash().hexdigest() == "ea44de0e2ef627be582282c02c48e94de0d58ec6"
-        assert obj.unsafe_hash().hexdigest() == "44204c8da394e878f7562c9aa2e37c2177f28b81"
+        assert (
+            a_list[0].unsafe_hash().hexdigest()
+            == "ea44de0e2ef627be582282c02c48e94de0d58ec6"
+        )
+        assert (
+            obj.unsafe_hash().hexdigest() == "44204c8da394e878f7562c9aa2e37c2177f28b81"
+        )
 
     def test_version(self):
         obj = self.good_cls("Hello", "World", "Python")
@@ -236,7 +270,9 @@ class TestMSONable:
                 "list5": [GMC(15, 15.0, "fifteen")],
             },
         ]
-        obj = GoodNestedMSONClass(a_list=a_list, b_dict=b_dict, c_list_dict_list=c_list_dict_list)
+        obj = GoodNestedMSONClass(
+            a_list=a_list, b_dict=b_dict, c_list_dict_list=c_list_dict_list
+        )
 
         obj_dict = obj.as_dict()
         obj2 = GoodNestedMSONClass.from_dict(obj_dict)
@@ -404,7 +440,10 @@ class TestJson:
 
         assert d["np_a"]["a"][0]["b"]["@module"] == "numpy"
         assert d["np_a"]["a"][0]["b"]["@class"] == "array"
-        assert d["np_a"]["a"][0]["b"]["data"] == [[[1.0, 2.0], [3.0, 4.0]], [[1.0, 1.0], [1.0, 1.0]]]
+        assert d["np_a"]["a"][0]["b"]["data"] == [
+            [[1.0, 2.0], [3.0, 4.0]],
+            [[1.0, 1.0], [1.0, 1.0]],
+        ]
         assert d["np_a"]["a"][0]["b"]["dtype"] == "complex64"
 
         obj = ClassContainingNumpyArray.from_dict(d)
@@ -413,7 +452,9 @@ class TestJson:
         assert obj.np_a["a"][0]["b"][0][1] == 2 + 1j
 
     def test_pandas(self):
-        cls = ClassContainingDataFrame(df=pd.DataFrame([{"a": 1, "b": 1}, {"a": 1, "b": 2}]))
+        cls = ClassContainingDataFrame(
+            df=pd.DataFrame([{"a": 1, "b": 1}, {"a": 1, "b": 2}])
+        )
 
         d = json.loads(MontyEncoder().encode(cls))
 
@@ -437,7 +478,9 @@ class TestJson:
         assert isinstance(obj.s, pd.Series)
         assert list(obj.s.a), [1, 2 == 3]
 
-        cls = ClassContainingSeries(s={"df": [pd.Series({"a": [1, 2, 3], "b": [4, 5, 6]})]})
+        cls = ClassContainingSeries(
+            s={"df": [pd.Series({"a": [1, 2, 3], "b": [4, 5, 6]})]}
+        )
 
         d = json.loads(MontyEncoder().encode(cls))
 
@@ -619,7 +662,9 @@ class TestJson:
         assert clean == s.to_dict()
 
     def test_redirect(self):
-        MSONable.REDIRECT["tests.test_json"] = {"test_class": {"@class": "GoodMSONClass", "@module": "tests.test_json"}}
+        MSONable.REDIRECT["tests.test_json"] = {
+            "test_class": {"@class": "GoodMSONClass", "@module": "tests.test_json"}
+        }
 
         d = {
             "@class": "test_class",
@@ -638,12 +683,17 @@ class TestJson:
 
     def test_redirect_settings_file(self):
         data = _load_redirect(os.path.join(test_dir, "test_settings.yaml"))
-        assert data == {"old_module": {"old_class": {"@class": "new_class", "@module": "new_module"}}}
+        assert data == {
+            "old_module": {
+                "old_class": {"@class": "new_class", "@module": "new_module"}
+            }
+        }
 
     def test_pydantic_integrations(self):
-        from pydantic import BaseModel
+        from pydantic import BaseModel, ValidationError
 
         global ModelWithMSONable  # allow model to be deserialized in test
+        global LimitedMSONClass
 
         class ModelWithMSONable(BaseModel):
             a: GoodMSONClass
@@ -651,6 +701,11 @@ class TestJson:
         test_object = ModelWithMSONable(a=GoodMSONClass(1, 1, 1))
         test_dict_object = ModelWithMSONable(a=test_object.a.as_dict())
         assert test_dict_object.a.a == test_object.a.a
+        dict_no_class = test_object.a.as_dict()
+        dict_no_class.pop("@class")
+        dict_no_class.pop("@module")
+        test_dict_object = ModelWithMSONable(a=dict_no_class)
+        assert test_dict_object.a.a == test_object.a.a
 
         assert test_object.model_json_schema() == {
             "title": "ModelWithMSONable",
@@ -691,6 +746,67 @@ class TestJson:
         assert isinstance(obj.a, GoodMSONClass)
         assert obj.a.b == 1
 
+        # check that a model that is not validated by pydantic still
+        # gets completely deserialized.
+        global ModelWithDict  # allow model to be deserialized in test
+
+        class ModelWithDict(BaseModel):
+            a: dict
+
+        test_object_with_dict = ModelWithDict(a={"x": GoodMSONClass(1, 1, 1)})
+        d = jsanitize(
+            test_object_with_dict, strict=True, enum_values=True, allow_bson=True
+        )
+        assert d == {
+            "a": {
+                "x": {
+                    "@module": "tests.test_json",
+                    "@class": "GoodMSONClass",
+                    "@version": "0.1",
+                    "a": 1,
+                    "b": 1,
+                    "c": 1,
+                    "d": 1,
+                    "values": [],
+                }
+            },
+            "@module": "tests.test_json",
+            "@class": "ModelWithDict",
+            "@version": "0.1",
+        }
+        obj = MontyDecoder().process_decoded(d)
+        assert isinstance(obj, BaseModel)
+        assert isinstance(obj.a["x"], GoodMSONClass)
+        assert obj.a["x"].b == 1
+
+        # check that if an MSONable object raises an exception during
+        # the model validation it is properly handled by pydantic
+        global ModelWithUnion  # allow model to be deserialized in test
+        global ModelWithLimited  # allow model to be deserialized in test
+
+        class ModelWithLimited(BaseModel):
+            a: LimitedMSONClass
+
+        class ModelWithUnion(BaseModel):
+            a: LimitedMSONClass | dict
+
+        limited_dict = jsanitize(ModelWithLimited(a=LimitedMSONClass(1)), strict=True)
+        assert ModelWithLimited.model_validate(limited_dict)
+        limited_dict["a"]["b"] = 2
+        with pytest.raises(ValidationError):
+            ModelWithLimited.model_validate(limited_dict)
+
+        limited_union_dict = jsanitize(
+            ModelWithUnion(a=LimitedMSONClass(1)), strict=True
+        )
+        validated_model = ModelWithUnion.model_validate(limited_union_dict)
+        assert isinstance(validated_model, ModelWithUnion)
+        assert isinstance(validated_model.a, LimitedMSONClass)
+        limited_union_dict["a"]["b"] = 2
+        validated_model = ModelWithUnion.model_validate(limited_union_dict)
+        assert isinstance(validated_model, ModelWithUnion)
+        assert isinstance(validated_model.a, dict)
+
     def test_dataclass(self):
         c = Coordinates([Point(1, 2), Point(3, 4)])
         d = c.as_dict()
@@ -709,3 +825,15 @@ class TestJson:
         str_ = json.dumps(ndc, cls=MontyEncoder)
         ndc2 = json.loads(str_, cls=MontyDecoder)
         assert isinstance(ndc2, NestedDataClass)
+
+    def test_enum(self):
+        s = MontyEncoder().encode(EnumNoAsDict.name_a)
+        p = MontyDecoder().decode(s)
+        assert p.name == "name_a"
+        assert p.value == "value_a"
+
+        na1 = EnumAsDict.name_a
+        d_ = na1.as_dict()
+        assert d_ == {"v": "value_a"}
+        na2 = EnumAsDict.from_dict(d_)
+        assert na2 == na1
